nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Cfg

Struct Cfg 

#[repr(transparent)]
pub struct Cfg(pub u32);
Configuration register

Tuple Fields

0: u32

Implementations

Source

impl Cfg

pub const fn adiclk(&self) -> Adiclk

Input Clock Select

pub const fn set_adiclk(&mut self, val: Adiclk)

Input Clock Select

pub const fn mode(&self) -> Mode

Conversion Mode Selection

pub const fn set_mode(&mut self, val: Mode)

Conversion Mode Selection

pub const fn adlsmp(&self) -> Adlsmp

Long Sample Time Configuration

pub const fn set_adlsmp(&mut self, val: Adlsmp)

Long Sample Time Configuration

pub const fn adiv(&self) -> Adiv

Clock Divide Select

pub const fn set_adiv(&mut self, val: Adiv)

Clock Divide Select

pub const fn adlpc(&self) -> Adlpc

Low-Power Configuration

pub const fn set_adlpc(&mut self, val: Adlpc)

Low-Power Configuration

pub const fn adsts(&self) -> Adsts

Defines the total sample time duration in number of full cycles

pub const fn set_adsts(&mut self, val: Adsts)

Defines the total sample time duration in number of full cycles

pub const fn adhsc(&self) -> Adhsc

High Speed Configuration

pub const fn set_adhsc(&mut self, val: Adhsc)

High Speed Configuration

pub const fn refsel(&self) -> Refsel

Voltage Reference Selection

pub const fn set_refsel(&mut self, val: Refsel)

Voltage Reference Selection

pub const fn adtrg(&self) -> Adtrg

Conversion Trigger Select

pub const fn set_adtrg(&mut self, val: Adtrg)

Conversion Trigger Select

pub const fn avgs(&self) -> Avgs

Hardware Average select

pub const fn set_avgs(&mut self, val: Avgs)

Hardware Average select

pub const fn ovwren(&self) -> Ovwren

Data Overwrite Enable

pub const fn set_ovwren(&mut self, val: Ovwren)

Data Overwrite Enable